@@ -28,7 +28,7 @@
 #include <libedata-book/e-book-backend.h>
 #include <libedata-book/e-book-backend-sexp.h>
 
-void 
+void
 string_to_dbt(const char *str, DBT *dbt)
 {
 	memset(dbt, 0, sizeof(dbt));
@@ -71,7 +71,7 @@ get_filename_from_uri (const char *uri)
  * Set the filename for db cacahe file.
  **/
 
-void 
+void
 e_book_backend_db_cache_set_filename(DB *db, const char *filename)
 {
 	DBT uid_dbt, vcard_dbt;
@@ -84,7 +84,7 @@ e_book_backend_db_cache_set_filename(DB *db, const char *filename)
 	if (db_error != 0) {
 		g_warning ("db->put failed with %d", db_error);
 	}
-	
+
 }
 
 /**
@@ -104,7 +104,7 @@ e_book_backend_db_cache_get_filename(DB *db)
 	string_to_dbt ("filename", &uid_dbt);
 	memset (&vcard_dbt, 0 , sizeof(vcard_dbt));
 	vcard_dbt.flags = DB_DBT_MALLOC;
-	
+
 	db_error = db->get (db, NULL, &uid_dbt, &vcard_dbt, 0);
 	if (db_error != 0) {
 		g_warning ("db-<get failed with %d", db_error);
@@ -117,7 +117,7 @@ e_book_backend_db_cache_get_filename(DB *db)
 	}
 }
 
-void 
+void
 e_book_backend_db_cache_set_time(DB *db, const char *t)
 {
 	DBT uid_dbt, vcard_dbt ;
@@ -178,16 +178,16 @@ e_book_backend_db_cache_get_contact (DB *db, const char *uid)
 	string_to_dbt (uid, &uid_dbt);
 	memset (&vcard_dbt, 0 , sizeof(vcard_dbt));
 	vcard_dbt.flags = DB_DBT_MALLOC;
-	
+
 	db_error = db->get (db, NULL, &uid_dbt, &vcard_dbt,0);
-	if (db_error != 0) { 
+	if (db_error != 0) {
 		g_warning ("db->get failed with %d", db_error);
 		return NULL;
 	}
-	
+
 	vcard_str = g_strdup (vcard_dbt.data);
 	g_free (vcard_dbt.data);
-	
+
 	return e_contact_new_from_vcard (vcard_str);
 }
 
@@ -218,10 +218,10 @@ e_book_backend_db_cache_add_contact (DB *db,
 		email = e_contact_get (contact, E_CONTACT_EMAIL_1);
 		printf ("no uid\n");
 		printf("name:%s, email:%s\n", name, email);
-		return FALSE; 
+		return FALSE;
 	}
 	string_to_dbt (uid, &uid_dbt);
-	
+
 	vcard_str = e_vcard_to_string (E_VCARD(contact), EVC_FORMAT_VCARD_30);
 	string_to_dbt (vcard_str, &vcard_dbt);
 
@@ -230,11 +230,11 @@ e_book_backend_db_cache_add_contact (DB *db,
 
 	g_free (vcard_str);
 
-	if (db_error != 0) { 
+	if (db_error != 0) {
 		g_warning ("db->put failed with %d", db_error);
 		return FALSE;
 	}
-	else 
+	else
 		return TRUE;
 }
 
@@ -250,7 +250,7 @@ e_book_backend_db_cache_add_contact (DB *db,
 gboolean
 e_book_backend_db_cache_remove_contact (DB *db,
 				    const char *uid)
-				      
+
 {
 	DBT        uid_dbt;
 	int        db_error;
@@ -260,11 +260,11 @@ e_book_backend_db_cache_remove_contact (DB *db,
 	string_to_dbt (uid, &uid_dbt);
 	db_error = db->del (db, NULL, &uid_dbt, 0);
 
-	if (db_error != 0) { 
+	if (db_error != 0) {
 		g_warning ("db->del failed with %d", db_error);
 		return FALSE;
 	}
-	else 
+	else
 		return TRUE;
 
 }
@@ -278,7 +278,7 @@ e_book_backend_db_cache_remove_contact (DB *db,
  *
  * Return value: %TRUE if the cache contains the contact, %FALSE otherwise.
  **/
-gboolean 
+gboolean
 e_book_backend_db_cache_check_contact (DB *db, const char *uid)
 {
 	DBT        uid_dbt, vcard_dbt;
@@ -289,9 +289,9 @@ e_book_backend_db_cache_check_contact (DB *db, const char *uid)
 	string_to_dbt (uid, &uid_dbt);
 	memset (&vcard_dbt, 0 , sizeof(vcard_dbt));
 	vcard_dbt.flags = DB_DBT_MALLOC;
-	
+
 	db_error = db->get (db, NULL, &uid_dbt, &vcard_dbt,0);
-	if (db_error != 0) 
+	if (db_error != 0)
 		return FALSE;
  	else {
 		free (vcard_dbt.data);
@@ -327,7 +327,7 @@ e_book_backend_db_cache_get_contacts (DB *db, const char *query)
 	}
 
 	db_error = db->cursor (db, NULL, &dbc, 0);
-	if (db_error != 0) { 
+	if (db_error != 0) {
 		g_warning ("db->cursor failed with %d", db_error);
 		return NULL;
 	}
@@ -340,7 +340,7 @@ e_book_backend_db_cache_get_contacts (DB *db, const char *query)
 		if (vcard_dbt.data && !strncmp (vcard_dbt.data, "BEGIN:VCARD", 11))
 		if (e_book_backend_sexp_match_vcard(sexp, vcard_dbt.data)) {
 			contact = e_contact_new_from_vcard (vcard_dbt.data);
-			list = g_list_append (list, contact);
+			list = g_list_prepend (list, contact);
 		}
 		db_error = dbc->c_get (dbc, &uid_dbt, &vcard_dbt, DB_NEXT);
 	}
@@ -348,7 +348,7 @@ e_book_backend_db_cache_get_contacts (DB *db, const char *query)
 	db_error = dbc->c_close (dbc);
 	if(db_error != 0)
 		g_warning ("db->c_close failed with %d", db_error);
-		
+
 	if (sexp)
 		g_object_unref (sexp);
 
@@ -371,17 +371,17 @@ e_book_backend_db_cache_search (DB *db, const char *query)
 {
 	GList *matching_contacts, *temp;
 	GPtrArray *ptr_array;
-	
+
 	matching_contacts = e_book_backend_db_cache_get_contacts (db, query);
 	ptr_array = g_ptr_array_new ();
-	
+
 	temp = matching_contacts;
 	for (; matching_contacts != NULL; matching_contacts = g_list_next (matching_contacts)) {
 		g_ptr_array_add (ptr_array, e_contact_get (matching_contacts->data, E_CONTACT_UID));
 		g_object_unref (matching_contacts->data);
 	}
 	g_list_free (temp);
-	
+
 	return ptr_array;
 }
 
@@ -393,18 +393,18 @@ e_book_backend_db_cache_search (DB *db, const char *query)
  *
  * Return value: %TRUE if cache exists, %FALSE if not.
  **/
-gboolean 
+gboolean
 e_book_backend_db_cache_exists (const char *uri)
 {
 	char *file_name;
 	gboolean exists = FALSE;
 	file_name = get_filename_from_uri (uri);
-	
+
 	if (file_name && g_file_test (file_name, G_FILE_TEST_EXISTS)) {
 		exists = TRUE;
 		g_free (file_name);
 	}
-	
+
 	return exists;
 }
 
@@ -412,7 +412,7 @@ e_book_backend_db_cache_exists (const char *uri)
  * e_book_backend_db_cache_set_populated:
  * @backend: an #EBookBackend
  *
- * Flags @cache as being populated - that is, it is up-to-date on the 
+ * Flags @cache as being populated - that is, it is up-to-date on the
  * contents of the book it's caching.
  **/
 void
@@ -424,10 +424,10 @@ e_book_backend_db_cache_set_populated (DB *db)
 	string_to_dbt ("populated", &uid_dbt);
 	string_to_dbt ("TRUE", &vcard_dbt);
 	db_error = db->put (db, NULL, &uid_dbt, &vcard_dbt, 0);
-	if (db_error != 0) { 
+	if (db_error != 0) {
 		g_warning ("db->put failed with %d", db_error);
 	}
-	
+
 }
 
 /**
@@ -443,7 +443,7 @@ e_book_backend_db_cache_is_populated (DB *db)
 {
 	DBT        uid_dbt, vcard_dbt;
 	int        db_error;
-	
+
 	string_to_dbt ("populated", &uid_dbt);
 	memset(&vcard_dbt, 0, sizeof(vcard_dbt));
 	vcard_dbt.flags = DB_DBT_MALLOC;
